@@ -67,7 +67,7 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
     settings_dialog = gtk.Dialog('%s' % (self.app_name), None, gtk.DIALOG_MODAL | gtk.DIALOG_NO_SEPARATOR, self.__config_ui.get_dialog_buttons())
     wpa = gtk.VBox()
     config_controls = {}
-    config_keys = self.__config.get_keys()
+    config_keys = [key for key in self.__config.get_keys() if key.startswith('settings')]
     config_keys.sort()
     for config_key in config_keys:
       name, ck_type, value = self.__config.get_entry(config_key)
