@@ -7,7 +7,7 @@ Bluetooth interface object
 '''
 
 
-import gobject
+import dbus, gobject
 from advifswlib.interfaces.Abstract import AbstractInterface
 from advpowcommon.util.execn import *
 
@@ -47,7 +47,8 @@ class BTInterface(AbstractInterface):
         self.connected_device.add(device)
         return 2, None, None
       else:
-        self.connected_device.remove(device)
+        try: self.connected_device.remove(device)
+        except KeyError, e: pass
         if len(self.connected_device) == 0: return self.get_status()
         else: return None, None, None
     else:
@@ -69,8 +70,11 @@ class BTInterface(AbstractInterface):
 
   def turn_off(self):
     for device in self.connected_device:
-      conndev_iface = dbus.Interface(self.get_bus().get_object('org.bluez', '%s/%s' % (self.bt_adapter_path, device)), self.bt_device_iface)
-      conndev_iface.Disconnect()
+      try:
+        conndev_iface = dbus.Interface(self.get_bus().get_object('org.bluez', '%s/%s' % (self.bt_adapter_path, device), introspect=True), self.bt_device_iface)
+        conndev_iface.Disconnect()
+      except:
+        pass
     gobject.idle_add(self.run_commands, False)
 
   def turn_mode(self, mode):
