@@ -39,7 +39,7 @@ class GSMInterface(AbstractInterface):
     'banner': (True, True, True),
     'value': 0,
     'strength': 0,
-    'modes': ('3G+GSM', 'GSM', '3G'),
+    'modes': ('gsm-3g+gsm', 'gsm-2g', 'gsm-3g'),
     'mode': 0
     }
     self.interfaces = {'Phone': [self.phone_iface, self.phone_path, self.phone_iiface, '', False], 'SSC': [self.gsm_module_iface, self.gsm_module_path, self.gsm_module_iface, '', True]}
