@@ -15,4 +15,4 @@ class AISCacher(Singleton):
     self.cacher = DITPixbufCacher(48)
 
 __cacher_singleton = AISCacher()
-def get_cacher(): return __cacher_singleton.cacher
+def get(): return __cacher_singleton.cacher
